# Sample Package Data

This directory contain the data required for testing. As integrating the content
into test function became impractical (e.g. inserting protein structure in Python
script). Also separating the test data with the script make the test code cleaner.
